/*
 * Copyright (c) 2011 by Intevation GmbH, Germany <info@intevation.de>
 *
 * This file is part of MXD2map.
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LICENCE.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 *
 * MXD2map has been developed on behalf of the
 * Bundesamt fuer Seeschifffahrt und Hydrographie (BSH) in Hamburg
 * by Intevation GmbH.
 *
 * Authors:
 * Raimund Renkert <raimund.renkert@intevation.de>
 * Bjoern Schilberg <bjoern.schilberg@intevation.de>
 * Stephan Holl <stephan.holl@intevation.de>
 */

package de.intevation.mxd.reader;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.ILineSymbol;
import com.esri.arcgis.display.MultiLayerLineSymbol;

import org.w3c.dom.Element;

/**
 * Reads multi layer line symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class MultiLayerLineSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(MultiLayerLineSymbolReader.class);

    /**
     * Private member.
     */
    private MultiLayerLineSymbol symbol;

    /**
     * Constructor with symbol
     *
     * @param symbol The symbol used to display lines.
     */
    public MultiLayerLineSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("constructor()");
        if(symbol instanceof MultiLayerLineSymbol) {
            this.symbol = (MultiLayerLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerLineSymbol!");
        }
    }

    /**
     * Constructor with symbol
     *
     * @param symbol The symbol used to display lines.
     */
    public MultiLayerLineSymbolReader(ILineSymbol symbol)
    throws Exception {
        logger.debug("constructor()");
        if(symbol instanceof MultiLayerLineSymbol) {
            this.symbol = (MultiLayerLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerLineSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read() {
        logger.debug("read()");
        try {
            for(int i = 0; i < symbol.getLayerCount(); i++) {
                ISymbol sym = (ISymbol)symbol.getLayer(i);
                ISymbolReader sreader = new LineSymbolReader(sym);
                sreader.setParent(parent);
                sreader.setUtil(util);
                sreader.read();
            }
        }
        catch(Exception e) {
            logger.error(
                "Could not read the symbol " +
                symbol.getClass().toString());
        }
        return parent;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
